

sycc
====

*time:2020-2021*

sycc:s是Simplify的意思,y是圆的意思,第一个c指代Cylinder（圆柱）,第二个c指代Ring（圆环）

+-+-+-+-+-

虹源三式:代表着只是个人第一次编辑的代码程序，虹代表作者写了许多为让运行程序能看到彩色字体而写了许多让程序颜色不那么单一的代码。
而本程序是用来辅助计算圆面、圆环、圆柱以目前作者知识量制作后续可能会更新圆锥、球等规则几何物体。

虹源三式这个名字则代表拥有运行可见彩色字体源自个人制作编写的三种几何图行算方式。

+-+-+-+-+-

**作者定制版**，若想使用(**原版**)请到:https://pypi.org/project/ycc/

与ycc差别并不大，只要是不恶搞就与sycc没区别，sycc仅仅是优化print和处理异常的方式


特点
-------
1.不会显得那么单调，加入了部分色彩（cmd或Terminal显示,pycharm无效）

2.能使用三种不同的计算器

3.不需要自己想算式

4.没有团队，作者“孤军作战”


Install and Upgrade and run
-------------------------------------------
使用pip下载:

::
    
    $pip install sycc


使用pip更新:

::
    
    $pip install --upgrade sycc


运行方式1:

::
            
    $sycc    

运行方式2:

::  
    
    from run import *


cmd或linux系统的终端使用运行方式1
python交互式窗口或py文件中使用运行方式2


权利
======
**本模块的修改权,解释权,著作权,保护作品完整权,复制权,改编权归作者所有，用户只有使用权,在此强调作者规定用户无复制权**

**作品翻译权归作者和用户**


提示与警告
--------------------------------
**LINCENSE/LINCENCE不是原版MIT许可证**

**tips:作者定制版本!请勿下载,在使用过程中作者视为管理员非用户**

**遵守当地法律，违法概不负责，解释权归作者所有** 

*作者制作，严禁盗取源代码*
*以下声明协议对作者无效*

使用代表您已阅读同意以下协议或提示

**IDLE:pydroid,python:>3.6**

**严禁盗源**

当你使用这个模块，出现程序错误时，你可以通过下面的电子邮件找到我

*qq邮箱*:**lwb29@qq.com**:

::
    
    当您正在使用此项目时，您默认同意以下内容。

    1.遵循你当地的法律，不要触犯法律。如果你触犯了法律，与作者无任何关系

    2.请合理使用使用本项目。如果您在使用项目时发现bug，可以发送emali到lwb@qq.com
    
    3.最终解释权归作者所有。

    4.别偷源代码！如果你发现有人窃取我的源代码，你可以通过电子邮件告诉我，我会给你一些补偿
    
    5.中国制造


问题
-------
q:为什么经常出现退出或切换模式?

a:如果不及时切换或退出则会出现各种报错,这也不是大家想看到的.

q:为什么需要密码?

a:此版本为作者定制版,暂不提供他人使用.

如果还有其他问题邮箱lwb29@qq.com.


New
======
1.倒计时动态化

2.优化显示

3.增加加载进度条

4.新的徽标

5.print优化完毕

6.sycc不支持Mac系统,因为作者无法测试

7.优化代码逻辑

Python in Android
-----------------------------
*推广*

使用方法:https://blog.csdn.net/m0_55474082/article/details/113996741

下载链接:https://www.lanzoux.com/b01zxzwhe/

密码:python


特别鸣谢
-----------
1.感谢(**九霄天**)的赐于本项目的名字(+-+-+-+-+-中内容)——*虹源三式*

2.感谢csdn，博客园，百度，qq群友以及其他提供资料的平台

3.感谢Miss.Wei

4.感谢dooccn.com(python测试网站)

5.感谢pypi,python,pydroid相关人员

7.当然在此的感谢人员数不胜数,在此作者统一感谢